@@ -101,6 +101,14 @@ impl<N: Network> LedgerState<N> {
     /// a read-only instance of `LedgerState` may only call immutable methods.
     ///
     pub fn open_writer<S: Storage, P: AsRef<Path>>(path: P) -> Result<Self> {
+        Self::open_writer_with_increment::<S, P>(path, 10_000)
+    }
+
+    /// This function is hidden, as it's intended to be used directly in tests only.
+    /// The `validation_increment` parameter determines the number of blocks to be
+    /// handled during the incremental validation process.
+    #[doc(hidden)]
+    pub fn open_writer_with_increment<S: Storage, P: AsRef<Path>>(path: P, validation_increment: u32) -> Result<Self> {
         // Open storage.
         let context = N::NETWORK_ID;
         let is_read_only = false;
@@ -162,11 +170,10 @@ impl<N: Network> LedgerState<N> {
         }
 
         // Iterate and append each block hash from genesis to tip to validate ledger state.
-        const INCREMENT: u32 = 2000;
         let mut start_block_height = 0u32;
         while start_block_height <= latest_block_height {
             // Compute the end block height (inclusive) for this iteration.
-            let end_block_height = std::cmp::min(start_block_height.saturating_add(INCREMENT), latest_block_height);
+            let end_block_height = std::cmp::min(start_block_height.saturating_add(validation_increment), latest_block_height);
 
             // Retrieve the block hashes.
             let block_hashes = ledger.get_block_hashes(start_block_height, end_block_height)?;
